@@ -12,7 +12,7 @@
 //! This section documents OpenCV's interface to the FLANN library. FLANN (Fast Library for Approximate
 //! Nearest Neighbors) is a library that contains a collection of algorithms optimized for fast nearest
 //! neighbor search in large datasets and for high dimensional features. More information about FLANN
-//! can be found in [Muja2009](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_Muja2009) .
+//! can be found in [Muja2009](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_Muja2009) .
 use crate::{mod_prelude::*, core, sys, types};
 pub mod prelude {
 	pub use { super::IndexParamsTraitConst, super::IndexParamsTrait, super::KDTreeIndexParamsTraitConst, super::KDTreeIndexParamsTrait, super::LinearIndexParamsTraitConst, super::LinearIndexParamsTrait, super::CompositeIndexParamsTraitConst, super::CompositeIndexParamsTrait, super::AutotunedIndexParamsTraitConst, super::AutotunedIndexParamsTrait, super::HierarchicalClusteringIndexParamsTraitConst, super::HierarchicalClusteringIndexParamsTrait, super::KMeansIndexParamsTraitConst, super::KMeansIndexParamsTrait, super::LshIndexParamsTraitConst, super::LshIndexParamsTrait, super::SavedIndexParamsTraitConst, super::SavedIndexParamsTrait, super::SearchParamsTraitConst, super::SearchParamsTrait, super::IndexTraitConst, super::IndexTrait };
@@ -231,13 +231,19 @@ pub type bucket_key = u32;
 pub type feature_index = u32;
 #[inline]
 pub fn flann_distance_type() -> Result<crate::flann::flann_distance_t> {
-	let ret = unsafe { sys::cvflann_flann_distance_type() }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cvflann_flann_distance_type(ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 #[inline]
 pub fn set_distance_type(distance_type: crate::flann::flann_distance_t, order: i32) -> Result<()> {
-	let ret = unsafe { sys::cvflann_set_distance_type_flann_distance_t_int(distance_type, order) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cvflann_set_distance_type_flann_distance_t_int(distance_type, order, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -290,7 +296,10 @@ impl AutotunedIndexParams {
 	/// * sample_fraction: 0.1f
 	#[inline]
 	pub fn new(target_precision: f32, build_weight: f32, memory_weight: f32, sample_fraction: f32) -> Result<crate::flann::AutotunedIndexParams> {
-		let ret = unsafe { sys::cv_flann_AutotunedIndexParams_AutotunedIndexParams_float_float_float_float(target_precision, build_weight, memory_weight, sample_fraction) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_AutotunedIndexParams_AutotunedIndexParams_float_float_float_float(target_precision, build_weight, memory_weight, sample_fraction, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::AutotunedIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -349,7 +358,10 @@ impl CompositeIndexParams {
 	/// * cb_index: 0.2f
 	#[inline]
 	pub fn new(trees: i32, branching: i32, iterations: i32, centers_init: crate::flann::flann_centers_init_t, cb_index: f32) -> Result<crate::flann::CompositeIndexParams> {
-		let ret = unsafe { sys::cv_flann_CompositeIndexParams_CompositeIndexParams_int_int_int_flann_centers_init_t_float(trees, branching, iterations, centers_init, cb_index) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_CompositeIndexParams_CompositeIndexParams_int_int_int_flann_centers_init_t_float(trees, branching, iterations, centers_init, cb_index, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::CompositeIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -407,7 +419,10 @@ impl HierarchicalClusteringIndexParams {
 	/// * leaf_size: 100
 	#[inline]
 	pub fn new(branching: i32, centers_init: crate::flann::flann_centers_init_t, trees: i32, leaf_size: i32) -> Result<crate::flann::HierarchicalClusteringIndexParams> {
-		let ret = unsafe { sys::cv_flann_HierarchicalClusteringIndexParams_HierarchicalClusteringIndexParams_int_flann_centers_init_t_int_int(branching, centers_init, trees, leaf_size) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_HierarchicalClusteringIndexParams_HierarchicalClusteringIndexParams_int_flann_centers_init_t_int_int(branching, centers_init, trees, leaf_size, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::HierarchicalClusteringIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -422,19 +437,28 @@ pub trait IndexTraitConst {
 	#[inline]
 	fn save(&self, filename: &str) -> Result<()> {
 		extern_container_arg!(filename);
-		let ret = unsafe { sys::cv_flann_Index_save_const_const_StringR(self.as_raw_Index(), filename.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_save_const_const_StringR(self.as_raw_Index(), filename.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_distance(&self) -> Result<crate::flann::flann_distance_t> {
-		let ret = unsafe { sys::cv_flann_Index_getDistance_const(self.as_raw_Index()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_getDistance_const(self.as_raw_Index(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_algorithm(&self) -> Result<crate::flann::flann_algorithm_t> {
-		let ret = unsafe { sys::cv_flann_Index_getAlgorithm_const(self.as_raw_Index()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_getAlgorithm_const(self.as_raw_Index(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -448,7 +472,10 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 	#[inline]
 	fn build(&mut self, features: &dyn core::ToInputArray, params: &crate::flann::IndexParams, dist_type: crate::flann::flann_distance_t) -> Result<()> {
 		input_array_arg!(features);
-		let ret = unsafe { sys::cv_flann_Index_build_const__InputArrayR_const_IndexParamsR_flann_distance_t(self.as_raw_mut_Index(), features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_build_const__InputArrayR_const_IndexParamsR_flann_distance_t(self.as_raw_mut_Index(), features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -459,7 +486,10 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 		input_array_arg!(query);
 		output_array_arg!(indices);
 		output_array_arg!(dists);
-		let ret = unsafe { sys::cv_flann_Index_knnSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), knn, params.as_raw_SearchParams()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_knnSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), knn, params.as_raw_SearchParams(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -470,7 +500,10 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 		input_array_arg!(query);
 		output_array_arg!(indices);
 		output_array_arg!(dists);
-		let ret = unsafe { sys::cv_flann_Index_radiusSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_double_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), radius, max_results, params.as_raw_SearchParams()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_radiusSearch_const__InputArrayR_const__OutputArrayR_const__OutputArrayR_double_int_const_SearchParamsR(self.as_raw_mut_Index(), query.as_raw__InputArray(), indices.as_raw__OutputArray(), dists.as_raw__OutputArray(), radius, max_results, params.as_raw_SearchParams(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -478,13 +511,19 @@ pub trait IndexTrait: crate::flann::IndexTraitConst {
 	fn load(&mut self, features: &dyn core::ToInputArray, filename: &str) -> Result<bool> {
 		input_array_arg!(features);
 		extern_container_arg!(filename);
-		let ret = unsafe { sys::cv_flann_Index_load_const__InputArrayR_const_StringR(self.as_raw_mut_Index(), features.as_raw__InputArray(), filename.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_load_const__InputArrayR_const_StringR(self.as_raw_mut_Index(), features.as_raw__InputArray(), filename.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn release(&mut self) -> Result<()> {
-		let ret = unsafe { sys::cv_flann_Index_release(self.as_raw_mut_Index()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_release(self.as_raw_mut_Index(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -516,7 +555,10 @@ impl crate::flann::IndexTrait for Index {
 impl Index {
 	#[inline]
 	pub fn default() -> Result<crate::flann::Index> {
-		let ret = unsafe { sys::cv_flann_Index_Index() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_Index(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::Index::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -526,7 +568,10 @@ impl Index {
 	#[inline]
 	pub fn new(features: &dyn core::ToInputArray, params: &crate::flann::IndexParams, dist_type: crate::flann::flann_distance_t) -> Result<crate::flann::Index> {
 		input_array_arg!(features);
-		let ret = unsafe { sys::cv_flann_Index_Index_const__InputArrayR_const_IndexParamsR_flann_distance_t(features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_Index_Index_const__InputArrayR_const_IndexParamsR_flann_distance_t(features.as_raw__InputArray(), params.as_raw_IndexParams(), dist_type, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::Index::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -542,7 +587,10 @@ pub trait IndexParamsTraitConst {
 	fn get_string(&self, key: &str, default_val: &str) -> Result<String> {
 		extern_container_arg!(key);
 		extern_container_arg!(default_val);
-		let ret = unsafe { sys::cv_flann_IndexParams_getString_const_const_StringR_const_StringR(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_getString_const_const_StringR_const_StringR(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { String::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -552,7 +600,10 @@ pub trait IndexParamsTraitConst {
 	#[inline]
 	fn get_int(&self, key: &str, default_val: i32) -> Result<i32> {
 		extern_container_arg!(key);
-		let ret = unsafe { sys::cv_flann_IndexParams_getInt_const_const_StringR_int(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_getInt_const_const_StringR_int(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -561,13 +612,19 @@ pub trait IndexParamsTraitConst {
 	#[inline]
 	fn get_double(&self, key: &str, default_val: f64) -> Result<f64> {
 		extern_container_arg!(key);
-		let ret = unsafe { sys::cv_flann_IndexParams_getDouble_const_const_StringR_double(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_getDouble_const_const_StringR_double(self.as_raw_IndexParams(), key.opencv_as_extern(), default_val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_all(&self, names: &mut core::Vector<String>, types: &mut core::Vector<crate::flann::FlannIndexType>, str_values: &mut core::Vector<String>, num_values: &mut core::Vector<f64>) -> Result<()> {
-		let ret = unsafe { sys::cv_flann_IndexParams_getAll_const_vector_String_R_vector_FlannIndexType_R_vector_String_R_vector_double_R(self.as_raw_IndexParams(), names.as_raw_mut_VectorOfString(), types.as_raw_mut_VectorOfFlannIndexType(), str_values.as_raw_mut_VectorOfString(), num_values.as_raw_mut_VectorOff64()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_getAll_const_vector_String_R_vector_FlannIndexType_R_vector_String_R_vector_double_R(self.as_raw_IndexParams(), names.as_raw_mut_VectorOfString(), types.as_raw_mut_VectorOfFlannIndexType(), str_values.as_raw_mut_VectorOfString(), num_values.as_raw_mut_VectorOff64(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -592,41 +649,59 @@ pub trait IndexParamsTrait: crate::flann::IndexParamsTraitConst {
 	fn set_string(&mut self, key: &str, value: &str) -> Result<()> {
 		extern_container_arg!(key);
 		extern_container_arg!(value);
-		let ret = unsafe { sys::cv_flann_IndexParams_setString_const_StringR_const_StringR(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_setString_const_StringR_const_StringR(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_int(&mut self, key: &str, value: i32) -> Result<()> {
 		extern_container_arg!(key);
-		let ret = unsafe { sys::cv_flann_IndexParams_setInt_const_StringR_int(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_setInt_const_StringR_int(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_double(&mut self, key: &str, value: f64) -> Result<()> {
 		extern_container_arg!(key);
-		let ret = unsafe { sys::cv_flann_IndexParams_setDouble_const_StringR_double(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_setDouble_const_StringR_double(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_float(&mut self, key: &str, value: f32) -> Result<()> {
 		extern_container_arg!(key);
-		let ret = unsafe { sys::cv_flann_IndexParams_setFloat_const_StringR_float(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_setFloat_const_StringR_float(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_bool(&mut self, key: &str, value: bool) -> Result<()> {
 		extern_container_arg!(key);
-		let ret = unsafe { sys::cv_flann_IndexParams_setBool_const_StringR_bool(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_setBool_const_StringR_bool(self.as_raw_mut_IndexParams(), key.opencv_as_extern(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_algorithm(&mut self, value: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_flann_IndexParams_setAlgorithm_int(self.as_raw_mut_IndexParams(), value) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_setAlgorithm_int(self.as_raw_mut_IndexParams(), value, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -658,7 +733,10 @@ impl crate::flann::IndexParamsTrait for IndexParams {
 impl IndexParams {
 	#[inline]
 	pub fn default() -> Result<crate::flann::IndexParams> {
-		let ret = unsafe { sys::cv_flann_IndexParams_IndexParams() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_IndexParams_IndexParams(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::IndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -711,7 +789,10 @@ impl KDTreeIndexParams {
 	/// * trees: 4
 	#[inline]
 	pub fn new(trees: i32) -> Result<crate::flann::KDTreeIndexParams> {
-		let ret = unsafe { sys::cv_flann_KDTreeIndexParams_KDTreeIndexParams_int(trees) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_KDTreeIndexParams_KDTreeIndexParams_int(trees, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::KDTreeIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -769,7 +850,10 @@ impl KMeansIndexParams {
 	/// * cb_index: 0.2f
 	#[inline]
 	pub fn new(branching: i32, iterations: i32, centers_init: crate::flann::flann_centers_init_t, cb_index: f32) -> Result<crate::flann::KMeansIndexParams> {
-		let ret = unsafe { sys::cv_flann_KMeansIndexParams_KMeansIndexParams_int_int_flann_centers_init_t_float(branching, iterations, centers_init, cb_index) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_KMeansIndexParams_KMeansIndexParams_int_int_flann_centers_init_t_float(branching, iterations, centers_init, cb_index, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::KMeansIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -822,7 +906,10 @@ impl crate::flann::LinearIndexParamsTrait for LinearIndexParams {
 impl LinearIndexParams {
 	#[inline]
 	pub fn default() -> Result<crate::flann::LinearIndexParams> {
-		let ret = unsafe { sys::cv_flann_LinearIndexParams_LinearIndexParams() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_LinearIndexParams_LinearIndexParams(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::LinearIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -875,7 +962,10 @@ impl crate::flann::LshIndexParamsTrait for LshIndexParams {
 impl LshIndexParams {
 	#[inline]
 	pub fn new(table_number: i32, key_size: i32, multi_probe_level: i32) -> Result<crate::flann::LshIndexParams> {
-		let ret = unsafe { sys::cv_flann_LshIndexParams_LshIndexParams_int_int_int(table_number, key_size, multi_probe_level) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_LshIndexParams_LshIndexParams_int_int_int(table_number, key_size, multi_probe_level, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::LshIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -929,7 +1019,10 @@ impl SavedIndexParams {
 	#[inline]
 	pub fn new(filename: &str) -> Result<crate::flann::SavedIndexParams> {
 		extern_container_arg!(filename);
-		let ret = unsafe { sys::cv_flann_SavedIndexParams_SavedIndexParams_const_StringR(filename.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_SavedIndexParams_SavedIndexParams_const_StringR(filename.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::SavedIndexParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -982,7 +1075,10 @@ impl crate::flann::SearchParamsTrait for SearchParams {
 impl SearchParams {
 	#[inline]
 	pub fn new(checks: i32, eps: f32, sorted: bool, explore_all_trees: bool) -> Result<crate::flann::SearchParams> {
-		let ret = unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool_bool(checks, eps, sorted, explore_all_trees) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool_bool(checks, eps, sorted, explore_all_trees, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::SearchParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -993,7 +1089,10 @@ impl SearchParams {
 	/// * sorted: true
 	#[inline]
 	pub fn new_1(checks: i32, eps: f32, sorted: bool) -> Result<crate::flann::SearchParams> {
-		let ret = unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool(checks, eps, sorted) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_flann_SearchParams_SearchParams_int_float_bool(checks, eps, sorted, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::flann::SearchParams::opencv_from_extern(ret) };
 		Ok(ret)
 	}
