@@ -23,7 +23,7 @@
 //!    # OpenGL support
 //!    # Qt New Functions
 //! 
-//!    ![image](https://docs.opencv.org/4.5.4/qtgui.png)
+//!    ![image](https://docs.opencv.org/4.5.5/qtgui.png)
 //! 
 //!    This figure explains new functionality implemented with Qt\* GUI. The new GUI provides a statusbar,
 //!    a toolbar, and a control panel. The control panel can have trackbars and buttonbars attached to it.
@@ -400,7 +400,10 @@ pub type TrackbarCallback = Option<Box<dyn FnMut(i32) -> () + Send + Sync + 'sta
 #[inline]
 pub fn add_text(img: &core::Mat, text: &str, org: core::Point, font: &crate::highgui::QtFont) -> Result<()> {
 	extern_container_arg!(text);
-	let ret = unsafe { sys::cv_addText_const_MatR_const_StringR_Point_const_QtFontR(img.as_raw_Mat(), text.opencv_as_extern(), org.opencv_as_extern(), font.as_raw_QtFont()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_addText_const_MatR_const_StringR_Point_const_QtFontR(img.as_raw_Mat(), text.opencv_as_extern(), org.opencv_as_extern(), font.as_raw_QtFont(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -429,7 +432,10 @@ pub fn add_text(img: &core::Mat, text: &str, org: core::Point, font: &crate::hig
 pub fn add_text_with_font(img: &core::Mat, text: &str, org: core::Point, name_font: &str, point_size: i32, color: core::Scalar, weight: i32, style: i32, spacing: i32) -> Result<()> {
 	extern_container_arg!(text);
 	extern_container_arg!(name_font);
-	let ret = unsafe { sys::cv_addText_const_MatR_const_StringR_Point_const_StringR_int_Scalar_int_int_int(img.as_raw_Mat(), text.opencv_as_extern(), org.opencv_as_extern(), name_font.opencv_as_extern(), point_size, color.opencv_as_extern(), weight, style, spacing) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_addText_const_MatR_const_StringR_Point_const_StringR_int_Scalar_int_int_int(img.as_raw_Mat(), text.opencv_as_extern(), org.opencv_as_extern(), name_font.opencv_as_extern(), point_size, color.opencv_as_extern(), weight, style, spacing, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -470,7 +476,10 @@ pub fn create_button(bar_name: &str, on_change: crate::highgui::ButtonCallback,
 	extern_container_arg!(bar_name);
 	callback_arg!(on_change_trampoline(state: i32, userdata: *mut c_void) -> () => userdata in callbacks => on_change(state: i32) -> ());
 	userdata_arg!(userdata in callbacks => on_change);
-	let ret = unsafe { sys::cv_createButton_const_StringR_ButtonCallback_voidX_int_bool(bar_name.opencv_as_extern(), on_change_trampoline, userdata, typ, initial_button_state) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createButton_const_StringR_ButtonCallback_voidX_int_bool(bar_name.opencv_as_extern(), on_change_trampoline, userdata, typ, initial_button_state, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -511,7 +520,10 @@ pub fn create_trackbar(trackbarname: &str, winname: &str, value: Option<&mut i32
 	extern_container_arg!(winname);
 	callback_arg!(on_change_trampoline(pos: i32, userdata: *mut c_void) -> () => userdata in callbacks => on_change(pos: i32) -> ());
 	userdata_arg!(userdata in callbacks => on_change);
-	let ret = unsafe { sys::cv_createTrackbar_const_StringR_const_StringR_intX_int_TrackbarCallback_voidX(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), value.map_or(::core::ptr::null_mut(), |value| value as *mut _), count, on_change_trampoline, userdata) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_createTrackbar_const_StringR_const_StringR_intX_int_TrackbarCallback_voidX(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), value.map_or(::core::ptr::null_mut(), |value| value as *mut _), count, on_change_trampoline, userdata, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -520,7 +532,10 @@ pub fn create_trackbar(trackbarname: &str, winname: &str, value: Option<&mut i32
 /// The function destroyAllWindows destroys all of the opened HighGUI windows.
 #[inline]
 pub fn destroy_all_windows() -> Result<()> {
-	let ret = unsafe { sys::cv_destroyAllWindows() }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_destroyAllWindows(ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -533,7 +548,10 @@ pub fn destroy_all_windows() -> Result<()> {
 #[inline]
 pub fn destroy_window(winname: &str) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_destroyWindow_const_StringR(winname.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_destroyWindow_const_StringR(winname.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -556,7 +574,10 @@ pub fn destroy_window(winname: &str) -> Result<()> {
 pub fn display_overlay(winname: &str, text: &str, delayms: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	extern_container_arg!(text);
-	let ret = unsafe { sys::cv_displayOverlay_const_StringR_const_StringR_int(winname.opencv_as_extern(), text.opencv_as_extern(), delayms) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_displayOverlay_const_StringR_const_StringR_int(winname.opencv_as_extern(), text.opencv_as_extern(), delayms, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -579,7 +600,10 @@ pub fn display_overlay(winname: &str, text: &str, delayms: i32) -> Result<()> {
 pub fn display_status_bar(winname: &str, text: &str, delayms: i32) -> Result<()> {
 	extern_container_arg!(winname);
 	extern_container_arg!(text);
-	let ret = unsafe { sys::cv_displayStatusBar_const_StringR_const_StringR_int(winname.opencv_as_extern(), text.opencv_as_extern(), delayms) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_displayStatusBar_const_StringR_const_StringR_int(winname.opencv_as_extern(), text.opencv_as_extern(), delayms, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -614,7 +638,10 @@ pub fn display_status_bar(winname: &str, text: &str, delayms: i32) -> Result<()>
 #[inline]
 pub fn font_qt(name_font: &str, point_size: i32, color: core::Scalar, weight: i32, style: i32, spacing: i32) -> Result<crate::highgui::QtFont> {
 	extern_container_arg!(name_font);
-	let ret = unsafe { sys::cv_fontQt_const_StringR_int_Scalar_int_int_int(name_font.opencv_as_extern(), point_size, color.opencv_as_extern(), weight, style, spacing) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_fontQt_const_StringR_int_Scalar_int_int_int(name_font.opencv_as_extern(), point_size, color.opencv_as_extern(), weight, style, spacing, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	let ret = unsafe { crate::highgui::QtFont::opencv_from_extern(ret) };
 	Ok(ret)
 }
@@ -640,7 +667,10 @@ pub fn font_qt(name_font: &str, point_size: i32, color: core::Scalar, weight: i3
 /// * flags: The mouse callback flags parameter.
 #[inline]
 pub fn get_mouse_wheel_delta(flags: i32) -> Result<i32> {
-	let ret = unsafe { sys::cv_getMouseWheelDelta_int(flags) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_getMouseWheelDelta_int(flags, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -661,7 +691,10 @@ pub fn get_mouse_wheel_delta(flags: i32) -> Result<i32> {
 pub fn get_trackbar_pos(trackbarname: &str, winname: &str) -> Result<i32> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_getTrackbarPos_const_StringR_const_StringR(trackbarname.opencv_as_extern(), winname.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_getTrackbarPos_const_StringR_const_StringR(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -676,7 +709,10 @@ pub fn get_trackbar_pos(trackbarname: &str, winname: &str) -> Result<i32> {
 #[inline]
 pub fn get_window_image_rect(winname: &str) -> Result<core::Rect> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_getWindowImageRect_const_StringR(winname.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_getWindowImageRect_const_StringR(winname.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -692,7 +728,10 @@ pub fn get_window_image_rect(winname: &str) -> Result<core::Rect> {
 #[inline]
 pub fn get_window_property(winname: &str, prop_id: i32) -> Result<f64> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_getWindowProperty_const_StringR_int(winname.opencv_as_extern(), prop_id) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_getWindowProperty_const_StringR_int(winname.opencv_as_extern(), prop_id, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -739,7 +778,10 @@ pub fn get_window_property(winname: &str, prop_id: i32) -> Result<f64> {
 pub fn imshow(winname: &str, mat: &dyn core::ToInputArray) -> Result<()> {
 	extern_container_arg!(winname);
 	input_array_arg!(mat);
-	let ret = unsafe { sys::cv_imshow_const_StringR_const__InputArrayR(winname.opencv_as_extern(), mat.as_raw__InputArray()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_imshow_const_StringR_const__InputArrayR(winname.opencv_as_extern(), mat.as_raw__InputArray(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -753,7 +795,10 @@ pub fn imshow(winname: &str, mat: &dyn core::ToInputArray) -> Result<()> {
 #[inline]
 pub fn load_window_parameters(window_name: &str) -> Result<()> {
 	extern_container_arg!(window_name);
-	let ret = unsafe { sys::cv_loadWindowParameters_const_StringR(window_name.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_loadWindowParameters_const_StringR(window_name.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -766,7 +811,10 @@ pub fn load_window_parameters(window_name: &str) -> Result<()> {
 #[inline]
 pub fn move_window(winname: &str, x: i32, y: i32) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_moveWindow_const_StringR_int_int(winname.opencv_as_extern(), x, y) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_moveWindow_const_StringR_int_int(winname.opencv_as_extern(), x, y, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -803,7 +851,10 @@ pub fn move_window(winname: &str, x: i32, y: i32) -> Result<()> {
 #[inline]
 pub fn named_window(winname: &str, flags: i32) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_namedWindow_const_StringR_int(winname.opencv_as_extern(), flags) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_namedWindow_const_StringR_int(winname.opencv_as_extern(), flags, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -822,7 +873,10 @@ pub fn named_window(winname: &str, flags: i32) -> Result<()> {
 /// active. If there are several HighGUI windows, any of them can be active.
 #[inline]
 pub fn poll_key() -> Result<i32> {
-	let ret = unsafe { sys::cv_pollKey() }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_pollKey(ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -846,7 +900,10 @@ pub fn poll_key() -> Result<i32> {
 #[inline]
 pub fn resize_window_size(winname: &str, size: core::Size) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_resizeWindow_const_StringR_const_SizeR(winname.opencv_as_extern(), &size) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_resizeWindow_const_StringR_const_SizeR(winname.opencv_as_extern(), &size, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -865,7 +922,10 @@ pub fn resize_window_size(winname: &str, size: core::Size) -> Result<()> {
 #[inline]
 pub fn resize_window(winname: &str, width: i32, height: i32) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_resizeWindow_const_StringR_int_int(winname.opencv_as_extern(), width, height) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_resizeWindow_const_StringR_int_int(winname.opencv_as_extern(), width, height, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -879,7 +939,10 @@ pub fn resize_window(winname: &str, width: i32, height: i32) -> Result<()> {
 #[inline]
 pub fn save_window_parameters(window_name: &str) -> Result<()> {
 	extern_container_arg!(window_name);
-	let ret = unsafe { sys::cv_saveWindowParameters_const_StringR(window_name.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_saveWindowParameters_const_StringR(window_name.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -908,7 +971,10 @@ pub fn save_window_parameters(window_name: &str) -> Result<()> {
 pub fn select_roi_for_window(window_name: &str, img: &dyn core::ToInputArray, show_crosshair: bool, from_center: bool) -> Result<core::Rect> {
 	extern_container_arg!(window_name);
 	input_array_arg!(img);
-	let ret = unsafe { sys::cv_selectROI_const_StringR_const__InputArrayR_bool_bool(window_name.opencv_as_extern(), img.as_raw__InputArray(), show_crosshair, from_center) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_selectROI_const_StringR_const__InputArrayR_bool_bool(window_name.opencv_as_extern(), img.as_raw__InputArray(), show_crosshair, from_center, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -938,7 +1004,10 @@ pub fn select_roi_for_window(window_name: &str, img: &dyn core::ToInputArray, sh
 #[inline]
 pub fn select_roi(img: &dyn core::ToInputArray, show_crosshair: bool, from_center: bool) -> Result<core::Rect> {
 	input_array_arg!(img);
-	let ret = unsafe { sys::cv_selectROI_const__InputArrayR_bool_bool(img.as_raw__InputArray(), show_crosshair, from_center) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_selectROI_const__InputArrayR_bool_bool(img.as_raw__InputArray(), show_crosshair, from_center, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -967,7 +1036,10 @@ pub fn select_roi(img: &dyn core::ToInputArray, show_crosshair: bool, from_cente
 pub fn select_rois(window_name: &str, img: &dyn core::ToInputArray, bounding_boxes: &mut core::Vector<core::Rect>, show_crosshair: bool, from_center: bool) -> Result<()> {
 	extern_container_arg!(window_name);
 	input_array_arg!(img);
-	let ret = unsafe { sys::cv_selectROIs_const_StringR_const__InputArrayR_vector_Rect_R_bool_bool(window_name.opencv_as_extern(), img.as_raw__InputArray(), bounding_boxes.as_raw_mut_VectorOfRect(), show_crosshair, from_center) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_selectROIs_const_StringR_const__InputArrayR_vector_Rect_R_bool_bool(window_name.opencv_as_extern(), img.as_raw__InputArray(), bounding_boxes.as_raw_mut_VectorOfRect(), show_crosshair, from_center, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -988,7 +1060,10 @@ pub fn set_mouse_callback(winname: &str, on_mouse: crate::highgui::MouseCallback
 	extern_container_arg!(winname);
 	callback_arg!(on_mouse_trampoline(event: i32, x: i32, y: i32, flags: i32, userdata: *mut c_void) -> () => userdata in callbacks => on_mouse(event: i32, x: i32, y: i32, flags: i32) -> ());
 	userdata_arg!(userdata in callbacks => on_mouse);
-	let ret = unsafe { sys::cv_setMouseCallback_const_StringR_MouseCallback_voidX(winname.opencv_as_extern(), on_mouse_trampoline, userdata) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setMouseCallback_const_StringR_MouseCallback_voidX(winname.opencv_as_extern(), on_mouse_trampoline, userdata, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -999,7 +1074,10 @@ pub fn set_mouse_callback(winname: &str, on_mouse: crate::highgui::MouseCallback
 #[inline]
 pub fn set_opengl_context(winname: &str) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_setOpenGlContext_const_StringR(winname.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setOpenGlContext_const_StringR(winname.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1052,7 +1130,10 @@ pub fn set_opengl_draw_callback(winname: &str, on_opengl_draw: crate::highgui::O
 	extern_container_arg!(winname);
 	callback_arg!(on_opengl_draw_trampoline(userdata: *mut c_void) -> () => userdata in callbacks => on_opengl_draw() -> ());
 	userdata_arg!(userdata in callbacks => on_opengl_draw);
-	let ret = unsafe { sys::cv_setOpenGlDrawCallback_const_StringR_OpenGlDrawCallback_voidX(winname.opencv_as_extern(), on_opengl_draw_trampoline, userdata) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setOpenGlDrawCallback_const_StringR_OpenGlDrawCallback_voidX(winname.opencv_as_extern(), on_opengl_draw_trampoline, userdata, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1074,7 +1155,10 @@ pub fn set_opengl_draw_callback(winname: &str, on_opengl_draw: crate::highgui::O
 pub fn set_trackbar_max(trackbarname: &str, winname: &str, maxval: i32) -> Result<()> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_setTrackbarMax_const_StringR_const_StringR_int(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), maxval) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setTrackbarMax_const_StringR_const_StringR_int(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), maxval, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1096,7 +1180,10 @@ pub fn set_trackbar_max(trackbarname: &str, winname: &str, maxval: i32) -> Resul
 pub fn set_trackbar_min(trackbarname: &str, winname: &str, minval: i32) -> Result<()> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_setTrackbarMin_const_StringR_const_StringR_int(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), minval) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setTrackbarMin_const_StringR_const_StringR_int(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), minval, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1118,7 +1205,10 @@ pub fn set_trackbar_min(trackbarname: &str, winname: &str, minval: i32) -> Resul
 pub fn set_trackbar_pos(trackbarname: &str, winname: &str, pos: i32) -> Result<()> {
 	extern_container_arg!(trackbarname);
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_setTrackbarPos_const_StringR_const_StringR_int(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), pos) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setTrackbarPos_const_StringR_const_StringR_int(trackbarname.opencv_as_extern(), winname.opencv_as_extern(), pos, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1133,7 +1223,10 @@ pub fn set_trackbar_pos(trackbarname: &str, winname: &str, pos: i32) -> Result<(
 #[inline]
 pub fn set_window_property(winname: &str, prop_id: i32, prop_value: f64) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_setWindowProperty_const_StringR_int_double(winname.opencv_as_extern(), prop_id, prop_value) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setWindowProperty_const_StringR_int_double(winname.opencv_as_extern(), prop_id, prop_value, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1145,26 +1238,38 @@ pub fn set_window_property(winname: &str, prop_id: i32, prop_value: f64) -> Resu
 pub fn set_window_title(winname: &str, title: &str) -> Result<()> {
 	extern_container_arg!(winname);
 	extern_container_arg!(title);
-	let ret = unsafe { sys::cv_setWindowTitle_const_StringR_const_StringR(winname.opencv_as_extern(), title.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_setWindowTitle_const_StringR_const_StringR(winname.opencv_as_extern(), title.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 #[inline]
 pub fn start_loop(pt2_func: Option<unsafe extern "C" fn(i32, *mut *mut c_char) -> i32>, argc: i32, argv: &mut [&str]) -> Result<i32> {
 	string_array_arg_mut!(argv);
-	let ret = unsafe { sys::cv_startLoop_int__X__int__charXX__int_charXX(pt2_func, argc, argv.as_mut_ptr()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_startLoop_int__X__int__charXX__int_charXX(pt2_func, argc, argv.as_mut_ptr(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 #[inline]
 pub fn start_window_thread() -> Result<i32> {
-	let ret = unsafe { sys::cv_startWindowThread() }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_startWindowThread(ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 #[inline]
 pub fn stop_loop() -> Result<()> {
-	let ret = unsafe { sys::cv_stopLoop() }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stopLoop(ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1175,7 +1280,10 @@ pub fn stop_loop() -> Result<()> {
 #[inline]
 pub fn update_window(winname: &str) -> Result<()> {
 	extern_container_arg!(winname);
-	let ret = unsafe { sys::cv_updateWindow_const_StringR(winname.opencv_as_extern()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_updateWindow_const_StringR(winname.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1190,7 +1298,10 @@ pub fn update_window(winname: &str) -> Result<()> {
 /// * delay: 0
 #[inline]
 pub fn wait_key_ex(delay: i32) -> Result<i32> {
-	let ret = unsafe { sys::cv_waitKeyEx_int(delay) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_waitKeyEx_int(delay, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1219,7 +1330,10 @@ pub fn wait_key_ex(delay: i32) -> Result<i32> {
 /// * delay: 0
 #[inline]
 pub fn wait_key(delay: i32) -> Result<i32> {
-	let ret = unsafe { sys::cv_waitKey_int(delay) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_waitKey_int(delay, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -1238,7 +1352,9 @@ pub trait QtFontTraitConst {
 	/// Color of the font. Scalar(blue_component, green_component, red_component[, alpha_component])
 	#[inline]
 	fn color(&self) -> core::Scalar {
-		let ret = unsafe { sys::cv_QtFont_getPropColor_const(self.as_raw_QtFont()) };
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_QtFont_getPropColor_const(self.as_raw_QtFont(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
 		ret
 	}
 	
