@@ -33,7 +33,7 @@
 //! to cover all objects in an image. Being able to perceive objects before identifying them is closely
 //! related to bottom up visual attention (saliency).
 //! 
-//! ![Saliency diagram](https://docs.opencv.org/4.5.4/saliency.png)
+//! ![Saliency diagram](https://docs.opencv.org/4.5.5/saliency.png)
 //! 
 //! To see how API works, try tracker demo:
 //! <https://github.com/fpuja/opencv_contrib/blob/saliencyModuleDevelop/modules/saliency/samples/computeSaliency.cpp>
@@ -63,19 +63,25 @@ pub trait MotionSaliency: crate::saliency::MotionSaliencyConst + crate::saliency
 ///  * [2]  B. Wang and P. Dudek "A Fast Self-tuning Background Subtraction Algorithm", in proc of IEEE Workshop on Change Detection, 2014
 ///  *
 /// 
-/// the Fast Self-tuning Background Subtraction Algorithm from [BinWangApr2014](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_BinWangApr2014)
+/// the Fast Self-tuning Background Subtraction Algorithm from [BinWangApr2014](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_BinWangApr2014)
 pub trait MotionSaliencyBinWangApr2014TraitConst: crate::saliency::MotionSaliencyConst {
 	fn as_raw_MotionSaliencyBinWangApr2014(&self) -> *const c_void;
 
 	#[inline]
 	fn get_image_width(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_getImageWidth_const(self.as_raw_MotionSaliencyBinWangApr2014()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_getImageWidth_const(self.as_raw_MotionSaliencyBinWangApr2014(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_image_height(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_getImageHeight_const(self.as_raw_MotionSaliencyBinWangApr2014()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_getImageHeight_const(self.as_raw_MotionSaliencyBinWangApr2014(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -88,7 +94,10 @@ pub trait MotionSaliencyBinWangApr2014Trait: crate::saliency::MotionSaliency + c
 	fn compute_saliency(&mut self, image: &dyn core::ToInputArray, saliency_map: &mut dyn core::ToOutputArray) -> Result<bool> {
 		input_array_arg!(image);
 		output_array_arg!(saliency_map);
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_MotionSaliencyBinWangApr2014(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_MotionSaliencyBinWangApr2014(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -99,7 +108,10 @@ pub trait MotionSaliencyBinWangApr2014Trait: crate::saliency::MotionSaliency + c
 	/// * H: height of input image
 	#[inline]
 	fn set_imagesize(&mut self, w: i32, h: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_setImagesize_int_int(self.as_raw_mut_MotionSaliencyBinWangApr2014(), w, h) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_setImagesize_int_int(self.as_raw_mut_MotionSaliencyBinWangApr2014(), w, h, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -107,19 +119,28 @@ pub trait MotionSaliencyBinWangApr2014Trait: crate::saliency::MotionSaliency + c
 	/// algorithm.
 	#[inline]
 	fn init(&mut self) -> Result<bool> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_init(self.as_raw_mut_MotionSaliencyBinWangApr2014()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_init(self.as_raw_mut_MotionSaliencyBinWangApr2014(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_image_width(&mut self, val: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_setImageWidth_int(self.as_raw_mut_MotionSaliencyBinWangApr2014(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_setImageWidth_int(self.as_raw_mut_MotionSaliencyBinWangApr2014(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_image_height(&mut self, val: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_setImageHeight_int(self.as_raw_mut_MotionSaliencyBinWangApr2014(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_setImageHeight_int(self.as_raw_mut_MotionSaliencyBinWangApr2014(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -132,7 +153,7 @@ pub trait MotionSaliencyBinWangApr2014Trait: crate::saliency::MotionSaliency + c
 ///  * [2]  B. Wang and P. Dudek "A Fast Self-tuning Background Subtraction Algorithm", in proc of IEEE Workshop on Change Detection, 2014
 ///  *
 /// 
-/// the Fast Self-tuning Background Subtraction Algorithm from [BinWangApr2014](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_BinWangApr2014)
+/// the Fast Self-tuning Background Subtraction Algorithm from [BinWangApr2014](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_BinWangApr2014)
 pub struct MotionSaliencyBinWangApr2014 {
 	ptr: *mut c_void
 }
@@ -183,14 +204,20 @@ impl crate::saliency::MotionSaliencyBinWangApr2014Trait for MotionSaliencyBinWan
 impl MotionSaliencyBinWangApr2014 {
 	#[inline]
 	pub fn default() -> Result<crate::saliency::MotionSaliencyBinWangApr2014> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_MotionSaliencyBinWangApr2014() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_MotionSaliencyBinWangApr2014(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::saliency::MotionSaliencyBinWangApr2014::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create() -> Result<core::Ptr<crate::saliency::MotionSaliencyBinWangApr2014>> {
-		let ret = unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_create() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_MotionSaliencyBinWangApr2014_create(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<crate::saliency::MotionSaliencyBinWangApr2014>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -210,31 +237,43 @@ pub trait Objectness: crate::saliency::ObjectnessConst + crate::saliency::Salien
 
 }
 
-/// the Binarized normed gradients algorithm from [BING](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_BING)
+/// the Binarized normed gradients algorithm from [BING](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_BING)
 pub trait ObjectnessBINGTraitConst: crate::saliency::ObjectnessConst {
 	fn as_raw_ObjectnessBING(&self) -> *const c_void;
 
 	#[inline]
 	fn write(&self) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_write_const(self.as_raw_ObjectnessBING()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_write_const(self.as_raw_ObjectnessBING(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_base(&self) -> Result<f64> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_getBase_const(self.as_raw_ObjectnessBING()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_getBase_const(self.as_raw_ObjectnessBING(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_nss(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_getNSS_const(self.as_raw_ObjectnessBING()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_getNSS_const(self.as_raw_ObjectnessBING(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_w(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_getW_const(self.as_raw_ObjectnessBING()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_getW_const(self.as_raw_ObjectnessBING(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -247,13 +286,19 @@ pub trait ObjectnessBINGTrait: crate::saliency::Objectness + crate::saliency::Ob
 	fn compute_saliency(&mut self, image: &dyn core::ToInputArray, saliency_map: &mut dyn core::ToOutputArray) -> Result<bool> {
 		input_array_arg!(image);
 		output_array_arg!(saliency_map);
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ObjectnessBING(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_ObjectnessBING(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn read(&mut self) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_read(self.as_raw_mut_ObjectnessBING()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_read(self.as_raw_mut_ObjectnessBING(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -264,7 +309,10 @@ pub trait ObjectnessBINGTrait: crate::saliency::Objectness + crate::saliency::Ob
 	/// object window.
 	#[inline]
 	fn getobjectness_values(&mut self) -> Result<core::Vector<f32>> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_getobjectnessValues(self.as_raw_mut_ObjectnessBING()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_getobjectnessValues(self.as_raw_mut_ObjectnessBING(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Vector::<f32>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -276,7 +324,10 @@ pub trait ObjectnessBINGTrait: crate::saliency::Objectness + crate::saliency::Ob
 	#[inline]
 	fn set_training_path(&mut self, training_path: &str) -> Result<()> {
 		extern_container_arg!(training_path);
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_setTrainingPath_const_StringR(self.as_raw_mut_ObjectnessBING(), training_path.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_setTrainingPath_const_StringR(self.as_raw_mut_ObjectnessBING(), training_path.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -290,31 +341,43 @@ pub trait ObjectnessBINGTrait: crate::saliency::Objectness + crate::saliency::Ob
 	#[inline]
 	fn set_bb_res_dir(&mut self, results_dir: &str) -> Result<()> {
 		extern_container_arg!(results_dir);
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_setBBResDir_const_StringR(self.as_raw_mut_ObjectnessBING(), results_dir.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_setBBResDir_const_StringR(self.as_raw_mut_ObjectnessBING(), results_dir.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_base(&mut self, val: f64) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_setBase_double(self.as_raw_mut_ObjectnessBING(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_setBase_double(self.as_raw_mut_ObjectnessBING(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_nss(&mut self, val: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_setNSS_int(self.as_raw_mut_ObjectnessBING(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_setNSS_int(self.as_raw_mut_ObjectnessBING(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_w(&mut self, val: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_setW_int(self.as_raw_mut_ObjectnessBING(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_setW_int(self.as_raw_mut_ObjectnessBING(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 }
 
-/// the Binarized normed gradients algorithm from [BING](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_BING)
+/// the Binarized normed gradients algorithm from [BING](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_BING)
 pub struct ObjectnessBING {
 	ptr: *mut c_void
 }
@@ -365,14 +428,20 @@ impl crate::saliency::ObjectnessBINGTrait for ObjectnessBING {
 impl ObjectnessBING {
 	#[inline]
 	pub fn default() -> Result<crate::saliency::ObjectnessBING> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_ObjectnessBING() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_ObjectnessBING(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::saliency::ObjectnessBING::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create() -> Result<core::Ptr<crate::saliency::ObjectnessBING>> {
-		let ret = unsafe { sys::cv_saliency_ObjectnessBING_create() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_ObjectnessBING_create(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<crate::saliency::ObjectnessBING>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -398,7 +467,10 @@ pub trait Saliency: core::AlgorithmTrait + crate::saliency::SaliencyConst {
 	fn compute_saliency(&mut self, image: &dyn core::ToInputArray, saliency_map: &mut dyn core::ToOutputArray) -> Result<bool> {
 		input_array_arg!(image);
 		output_array_arg!(saliency_map);
-		let ret = unsafe { sys::cv_saliency_Saliency_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_Saliency(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_Saliency_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_Saliency(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -432,13 +504,16 @@ pub trait StaticSaliency: crate::saliency::Saliency + crate::saliency::StaticSal
 	fn compute_binary_map(&mut self, _saliency_map: &dyn core::ToInputArray, _binary_map: &mut dyn core::ToOutputArray) -> Result<bool> {
 		input_array_arg!(_saliency_map);
 		output_array_arg!(_binary_map);
-		let ret = unsafe { sys::cv_saliency_StaticSaliency_computeBinaryMap_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_StaticSaliency(), _saliency_map.as_raw__InputArray(), _binary_map.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliency_computeBinaryMap_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_StaticSaliency(), _saliency_map.as_raw__InputArray(), _binary_map.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 }
 
-/// the Fine Grained Saliency approach from [FGS](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_FGS)
+/// the Fine Grained Saliency approach from [FGS](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_FGS)
 /// 
 /// This method calculates saliency based on center-surround differences.
 /// High resolution saliency maps are generated in real time by using integral images.
@@ -454,13 +529,16 @@ pub trait StaticSaliencyFineGrainedTrait: crate::saliency::StaticSaliency + crat
 	fn compute_saliency(&mut self, image: &dyn core::ToInputArray, saliency_map: &mut dyn core::ToOutputArray) -> Result<bool> {
 		input_array_arg!(image);
 		output_array_arg!(saliency_map);
-		let ret = unsafe { sys::cv_saliency_StaticSaliencyFineGrained_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_StaticSaliencyFineGrained(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencyFineGrained_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_StaticSaliencyFineGrained(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 }
 
-/// the Fine Grained Saliency approach from [FGS](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_FGS)
+/// the Fine Grained Saliency approach from [FGS](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_FGS)
 /// 
 /// This method calculates saliency based on center-surround differences.
 /// High resolution saliency maps are generated in real time by using integral images.
@@ -514,14 +592,20 @@ impl crate::saliency::StaticSaliencyFineGrainedTrait for StaticSaliencyFineGrain
 impl StaticSaliencyFineGrained {
 	#[inline]
 	pub fn default() -> Result<crate::saliency::StaticSaliencyFineGrained> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencyFineGrained_StaticSaliencyFineGrained() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencyFineGrained_StaticSaliencyFineGrained(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::saliency::StaticSaliencyFineGrained::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create() -> Result<core::Ptr<crate::saliency::StaticSaliencyFineGrained>> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencyFineGrained_create() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencyFineGrained_create(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<crate::saliency::StaticSaliencyFineGrained>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -530,7 +614,7 @@ impl StaticSaliencyFineGrained {
 
 boxed_cast_base! { StaticSaliencyFineGrained, core::Algorithm, cv_StaticSaliencyFineGrained_to_Algorithm }
 
-/// the Spectral Residual approach from  [SR](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_SR)
+/// the Spectral Residual approach from  [SR](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_SR)
 /// 
 /// Starting from the principle of natural image statistics, this method simulate the behavior of
 /// pre-attentive visual search. The algorithm analyze the log spectrum of each image and obtain the
@@ -541,19 +625,28 @@ pub trait StaticSaliencySpectralResidualTraitConst: crate::saliency::StaticSalie
 
 	#[inline]
 	fn write(&self, fs: &mut core::FileStorage) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_write_const_FileStorageR(self.as_raw_StaticSaliencySpectralResidual(), fs.as_raw_mut_FileStorage()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_write_const_FileStorageR(self.as_raw_StaticSaliencySpectralResidual(), fs.as_raw_mut_FileStorage(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_image_width(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_getImageWidth_const(self.as_raw_StaticSaliencySpectralResidual()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_getImageWidth_const(self.as_raw_StaticSaliencySpectralResidual(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn get_image_height(&self) -> Result<i32> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_getImageHeight_const(self.as_raw_StaticSaliencySpectralResidual()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_getImageHeight_const(self.as_raw_StaticSaliencySpectralResidual(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -566,31 +659,43 @@ pub trait StaticSaliencySpectralResidualTrait: crate::saliency::StaticSaliency +
 	fn compute_saliency(&mut self, image: &dyn core::ToInputArray, saliency_map: &mut dyn core::ToOutputArray) -> Result<bool> {
 		input_array_arg!(image);
 		output_array_arg!(saliency_map);
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_StaticSaliencySpectralResidual(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_computeSaliency_const__InputArrayR_const__OutputArrayR(self.as_raw_mut_StaticSaliencySpectralResidual(), image.as_raw__InputArray(), saliency_map.as_raw__OutputArray(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn read(&mut self, fn_: &core::FileNode) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_read_const_FileNodeR(self.as_raw_mut_StaticSaliencySpectralResidual(), fn_.as_raw_FileNode()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_read_const_FileNodeR(self.as_raw_mut_StaticSaliencySpectralResidual(), fn_.as_raw_FileNode(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_image_width(&mut self, val: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_setImageWidth_int(self.as_raw_mut_StaticSaliencySpectralResidual(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_setImageWidth_int(self.as_raw_mut_StaticSaliencySpectralResidual(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 	#[inline]
 	fn set_image_height(&mut self, val: i32) -> Result<()> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_setImageHeight_int(self.as_raw_mut_StaticSaliencySpectralResidual(), val) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_setImageHeight_int(self.as_raw_mut_StaticSaliencySpectralResidual(), val, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
 }
 
-/// the Spectral Residual approach from  [SR](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_SR)
+/// the Spectral Residual approach from  [SR](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_SR)
 /// 
 /// Starting from the principle of natural image statistics, this method simulate the behavior of
 /// pre-attentive visual search. The algorithm analyze the log spectrum of each image and obtain the
@@ -646,14 +751,20 @@ impl crate::saliency::StaticSaliencySpectralResidualTrait for StaticSaliencySpec
 impl StaticSaliencySpectralResidual {
 	#[inline]
 	pub fn default() -> Result<crate::saliency::StaticSaliencySpectralResidual> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_StaticSaliencySpectralResidual() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_StaticSaliencySpectralResidual(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { crate::saliency::StaticSaliencySpectralResidual::opencv_from_extern(ret) };
 		Ok(ret)
 	}
 	
 	#[inline]
 	pub fn create() -> Result<core::Ptr<crate::saliency::StaticSaliencySpectralResidual>> {
-		let ret = unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_create() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_saliency_StaticSaliencySpectralResidual_create(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<crate::saliency::StaticSaliencySpectralResidual>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
