@@ -29,14 +29,20 @@ pub const CV_STAR_KERNEL: i32 = 6;
 /// *
 #[inline]
 pub fn census_transform(image1: &core::Mat, image2: &core::Mat, kernel_size: i32, dist1: &mut core::Mat, dist2: &mut core::Mat, typ: i32) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_censusTransform_const_MatR_const_MatR_int_MatR_MatR_const_int(image1.as_raw_Mat(), image2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), typ) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_censusTransform_const_MatR_const_MatR_int_MatR_MatR_const_int(image1.as_raw_Mat(), image2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), typ, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 /// single image census transform
 #[inline]
 pub fn census_transform_1(image1: &core::Mat, kernel_size: i32, dist1: &mut core::Mat, typ: i32) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_censusTransform_const_MatR_int_MatR_const_int(image1.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), typ) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_censusTransform_const_MatR_int_MatR_const_int(image1.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), typ, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -50,7 +56,10 @@ pub fn census_transform_1(image1: &core::Mat, kernel_size: i32, dist1: &mut core
 /// * integral_image2: Mat()
 #[inline]
 pub fn modified_census_transform(img1: &core::Mat, img2: &core::Mat, kernel_size: i32, dist1: &mut core::Mat, dist2: &mut core::Mat, typ: i32, t: i32, integral_image1: &core::Mat, integral_image2: &core::Mat) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_modifiedCensusTransform_const_MatR_const_MatR_int_MatR_MatR_const_int_int_const_MatR_const_MatR(img1.as_raw_Mat(), img2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), typ, t, integral_image1.as_raw_Mat(), integral_image2.as_raw_Mat()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_modifiedCensusTransform_const_MatR_const_MatR_int_MatR_MatR_const_int_int_const_MatR_const_MatR(img1.as_raw_Mat(), img2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), typ, t, integral_image1.as_raw_Mat(), integral_image2.as_raw_Mat(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -61,21 +70,30 @@ pub fn modified_census_transform(img1: &core::Mat, img2: &core::Mat, kernel_size
 /// * integral_image: Mat()
 #[inline]
 pub fn modified_census_transform_1(img1: &core::Mat, kernel_size: i32, dist: &mut core::Mat, typ: i32, t: i32, integral_image: &core::Mat) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_modifiedCensusTransform_const_MatR_int_MatR_const_int_int_const_MatR(img1.as_raw_Mat(), kernel_size, dist.as_raw_mut_Mat(), typ, t, integral_image.as_raw_Mat()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_modifiedCensusTransform_const_MatR_int_MatR_const_int_int_const_MatR(img1.as_raw_Mat(), kernel_size, dist.as_raw_mut_Mat(), typ, t, integral_image.as_raw_Mat(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 /// in a 9x9 kernel only certain positions are choosen
 #[inline]
 pub fn star_census_transform(img1: &core::Mat, img2: &core::Mat, kernel_size: i32, dist1: &mut core::Mat, dist2: &mut core::Mat) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_starCensusTransform_const_MatR_const_MatR_int_MatR_MatR(img1.as_raw_Mat(), img2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_starCensusTransform_const_MatR_const_MatR_int_MatR_MatR(img1.as_raw_Mat(), img2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 /// single image version of star kernel
 #[inline]
 pub fn star_census_transform_1(img1: &core::Mat, kernel_size: i32, dist: &mut core::Mat) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_starCensusTransform_const_MatR_int_MatR(img1.as_raw_Mat(), kernel_size, dist.as_raw_mut_Mat()) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_starCensusTransform_const_MatR_int_MatR(img1.as_raw_Mat(), kernel_size, dist.as_raw_mut_Mat(), ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -84,14 +102,20 @@ pub fn star_census_transform_1(img1: &core::Mat, kernel_size: i32, dist: &mut co
 /// *
 #[inline]
 pub fn symetric_census_transform(img1: &core::Mat, img2: &core::Mat, kernel_size: i32, dist1: &mut core::Mat, dist2: &mut core::Mat, typ: i32) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_symetricCensusTransform_const_MatR_const_MatR_int_MatR_MatR_const_int(img1.as_raw_Mat(), img2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), typ) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_symetricCensusTransform_const_MatR_const_MatR_int_MatR_MatR_const_int(img1.as_raw_Mat(), img2.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), dist2.as_raw_mut_Mat(), typ, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
 /// single version of census transform
 #[inline]
 pub fn symetric_census_transform_1(img1: &core::Mat, kernel_size: i32, dist1: &mut core::Mat, typ: i32) -> Result<()> {
-	let ret = unsafe { sys::cv_stereo_symetricCensusTransform_const_MatR_int_MatR_const_int(img1.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), typ) }.into_result()?;
+	return_send!(via ocvrs_return);
+	unsafe { sys::cv_stereo_symetricCensusTransform_const_MatR_int_MatR_const_int(img1.as_raw_Mat(), kernel_size, dist1.as_raw_mut_Mat(), typ, ocvrs_return.as_mut_ptr()) };
+	return_receive!(unsafe ocvrs_return => ret);
+	let ret = ret.into_result()?;
 	Ok(ret)
 }
 
@@ -109,7 +133,10 @@ opencv_type_simple! { crate::stereo::MatchQuasiDense }
 impl MatchQuasiDense {
 	#[inline]
 	pub fn default() -> Result<crate::stereo::MatchQuasiDense> {
-		let ret = unsafe { sys::cv_stereo_MatchQuasiDense_MatchQuasiDense() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_MatchQuasiDense_MatchQuasiDense(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -157,16 +184,18 @@ impl PropagationParameters {
 /// that are not previously computed. New matches are stored in the seed priority queue and used as seeds.
 /// The propagation process ends when no additional matches can be retrieved.
 /// ## See also
-/// This code represents the work presented in [Stoyanov2010](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_Stoyanov2010).
-/// If this code is useful for your work please cite [Stoyanov2010](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_Stoyanov2010).
+/// This code represents the work presented in [Stoyanov2010](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_Stoyanov2010).
+/// If this code is useful for your work please cite [Stoyanov2010](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_Stoyanov2010).
 /// 
-/// Also the original growing scheme idea is described in [Lhuillier2000](https://docs.opencv.org/4.5.4/d0/de3/citelist.html#CITEREF_Lhuillier2000)
+/// Also the original growing scheme idea is described in [Lhuillier2000](https://docs.opencv.org/4.5.5/d0/de3/citelist.html#CITEREF_Lhuillier2000)
 pub trait QuasiDenseStereoConst {
 	fn as_raw_QuasiDenseStereo(&self) -> *const c_void;
 
 	#[inline]
 	fn param(&self) -> crate::stereo::PropagationParameters {
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_getPropParam_const(self.as_raw_QuasiDenseStereo()) };
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_getPropParam_const(self.as_raw_QuasiDenseStereo(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
 		ret
 	}
 	
@@ -200,7 +229,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	#[inline]
 	fn load_parameters(&mut self, filepath: &str) -> Result<i32> {
 		extern_container_arg!(mut filepath);
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_loadParameters_String(self.as_raw_mut_QuasiDenseStereo(), filepath.opencv_as_extern_mut()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_loadParameters_String(self.as_raw_mut_QuasiDenseStereo(), filepath.opencv_as_extern_mut(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -217,7 +249,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	#[inline]
 	fn save_parameters(&mut self, filepath: &str) -> Result<i32> {
 		extern_container_arg!(mut filepath);
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_saveParameters_String(self.as_raw_mut_QuasiDenseStereo(), filepath.opencv_as_extern_mut()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_saveParameters_String(self.as_raw_mut_QuasiDenseStereo(), filepath.opencv_as_extern_mut(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -230,7 +265,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	/// Note: The returned Match elements inside the sMatches vector, do not use corr member.
 	#[inline]
 	fn get_sparse_matches(&mut self, s_matches: &mut core::Vector<crate::stereo::MatchQuasiDense>) -> Result<()> {
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_getSparseMatches_vector_MatchQuasiDense_R(self.as_raw_mut_QuasiDenseStereo(), s_matches.as_raw_mut_VectorOfMatchQuasiDense()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_getSparseMatches_vector_MatchQuasiDense_R(self.as_raw_mut_QuasiDenseStereo(), s_matches.as_raw_mut_VectorOfMatchQuasiDense(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -243,7 +281,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	/// Note: The returned Match elements inside the sMatches vector, do not use corr member.
 	#[inline]
 	fn get_dense_matches(&mut self, dense_matches: &mut core::Vector<crate::stereo::MatchQuasiDense>) -> Result<()> {
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_getDenseMatches_vector_MatchQuasiDense_R(self.as_raw_mut_QuasiDenseStereo(), dense_matches.as_raw_mut_VectorOfMatchQuasiDense()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_getDenseMatches_vector_MatchQuasiDense_R(self.as_raw_mut_QuasiDenseStereo(), dense_matches.as_raw_mut_VectorOfMatchQuasiDense(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -262,7 +303,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	/// quasiDenseMatching
 	#[inline]
 	fn process(&mut self, img_left: &core::Mat, img_right: &core::Mat) -> Result<()> {
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_process_const_MatR_const_MatR(self.as_raw_mut_QuasiDenseStereo(), img_left.as_raw_Mat(), img_right.as_raw_Mat()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_process_const_MatR_const_MatR(self.as_raw_mut_QuasiDenseStereo(), img_left.as_raw_Mat(), img_right.as_raw_Mat(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -276,7 +320,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	/// Note: This method should be always called after process, otherwise the matches will not be correct.
 	#[inline]
 	fn get_match(&mut self, x: i32, y: i32) -> Result<core::Point2f> {
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_getMatch_const_int_const_int(self.as_raw_mut_QuasiDenseStereo(), x, y) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_getMatch_const_int_const_int(self.as_raw_mut_QuasiDenseStereo(), x, y, ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -290,7 +337,10 @@ pub trait QuasiDenseStereo: crate::stereo::QuasiDenseStereoConst {
 	/// quantizeDisparity
 	#[inline]
 	fn get_disparity(&mut self) -> Result<core::Mat> {
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_getDisparity(self.as_raw_mut_QuasiDenseStereo()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_getDisparity(self.as_raw_mut_QuasiDenseStereo(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Mat::opencv_from_extern(ret) };
 		Ok(ret)
 	}
@@ -303,7 +353,10 @@ impl dyn QuasiDenseStereo + '_ {
 	#[inline]
 	pub fn create(mono_img_size: core::Size, param_filepath: &str) -> Result<core::Ptr<dyn crate::stereo::QuasiDenseStereo>> {
 		extern_container_arg!(mut param_filepath);
-		let ret = unsafe { sys::cv_stereo_QuasiDenseStereo_create_Size_String(mono_img_size.opencv_as_extern(), param_filepath.opencv_as_extern_mut()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_stereo_QuasiDenseStereo_create_Size_String(mono_img_size.opencv_as_extern(), param_filepath.opencv_as_extern_mut(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::stereo::QuasiDenseStereo>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
