@@ -22,7 +22,10 @@ pub trait WBDetectorConst {
 	/// * fs: FileStorage for output
 	#[inline]
 	fn write(&self, fs: &mut core::FileStorage) -> Result<()> {
-		let ret = unsafe { sys::cv_xobjdetect_WBDetector_write_const_FileStorageR(self.as_raw_WBDetector(), fs.as_raw_mut_FileStorage()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_xobjdetect_WBDetector_write_const_FileStorageR(self.as_raw_WBDetector(), fs.as_raw_mut_FileStorage(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -36,7 +39,10 @@ pub trait WBDetector: crate::xobjdetect::WBDetectorConst {
 	/// * node: FileNode for input
 	#[inline]
 	fn read(&mut self, node: &core::FileNode) -> Result<()> {
-		let ret = unsafe { sys::cv_xobjdetect_WBDetector_read_const_FileNodeR(self.as_raw_mut_WBDetector(), node.as_raw_FileNode()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_xobjdetect_WBDetector_read_const_FileNodeR(self.as_raw_mut_WBDetector(), node.as_raw_FileNode(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -48,7 +54,10 @@ pub trait WBDetector: crate::xobjdetect::WBDetectorConst {
 	fn train(&mut self, pos_samples: &str, neg_imgs: &str) -> Result<()> {
 		extern_container_arg!(pos_samples);
 		extern_container_arg!(neg_imgs);
-		let ret = unsafe { sys::cv_xobjdetect_WBDetector_train_const_stringR_const_stringR(self.as_raw_mut_WBDetector(), pos_samples.opencv_as_extern(), neg_imgs.opencv_as_extern()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_xobjdetect_WBDetector_train_const_stringR_const_stringR(self.as_raw_mut_WBDetector(), pos_samples.opencv_as_extern(), neg_imgs.opencv_as_extern(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -59,7 +68,10 @@ pub trait WBDetector: crate::xobjdetect::WBDetectorConst {
 	/// * confidences: Confidence values for bounding boxes output vector
 	#[inline]
 	fn detect(&mut self, img: &core::Mat, bboxes: &mut core::Vector<core::Rect>, confidences: &mut core::Vector<f64>) -> Result<()> {
-		let ret = unsafe { sys::cv_xobjdetect_WBDetector_detect_const_MatR_vector_Rect_R_vector_double_R(self.as_raw_mut_WBDetector(), img.as_raw_Mat(), bboxes.as_raw_mut_VectorOfRect(), confidences.as_raw_mut_VectorOff64()) }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_xobjdetect_WBDetector_detect_const_MatR_vector_Rect_R_vector_double_R(self.as_raw_mut_WBDetector(), img.as_raw_Mat(), bboxes.as_raw_mut_VectorOfRect(), confidences.as_raw_mut_VectorOff64(), ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		Ok(ret)
 	}
 	
@@ -69,7 +81,10 @@ impl dyn WBDetector + '_ {
 	/// Create instance of WBDetector
 	#[inline]
 	pub fn create() -> Result<core::Ptr<dyn crate::xobjdetect::WBDetector>> {
-		let ret = unsafe { sys::cv_xobjdetect_WBDetector_create() }.into_result()?;
+		return_send!(via ocvrs_return);
+		unsafe { sys::cv_xobjdetect_WBDetector_create(ocvrs_return.as_mut_ptr()) };
+		return_receive!(unsafe ocvrs_return => ret);
+		let ret = ret.into_result()?;
 		let ret = unsafe { core::Ptr::<dyn crate::xobjdetect::WBDetector>::opencv_from_extern(ret) };
 		Ok(ret)
 	}
